==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/he.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "האם לשתף את השיתוף החיצוני {name} שהתקבל מ- {owner}@{remote}?",
    "Remote share" : "שיתוף חיצוני",
    "Remote share password" : "סיסמת שיתוף חיצוני",
    "Cancel" : "ביטול",
    "Add remote share" : "הוספת שיתוף חיצוני",
    "Copy" : "העתק",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Server to server sharing is not enabled on this server" : "שיתוף שרת לשרת לא מופעל בשרת זה",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "File is already shared with %s" : "הקובץ כבר משותף עם %s",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "Federated sharing" : "שיתוף מאוגד",
    "Accept" : "אישור",
    "Decline" : "סירוב",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "שיתוף איתי באמצעות מספר זהות שרת ה- #Nextcloud המאוגד שלי, ניתן לראות %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "שיתוף איתי באמצעות מספר זהות שרת ה- #Nextcloud המאוגד שלי",
    "Sharing" : "שיתוף",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Open documentation" : "תיעוד פתוח",
    "Allow users on this server to send shares to other servers" : "מאפשר למשתמשים בשרת זה לשלוח שיתופים לשרתים אחרים",
    "Allow users on this server to receive shares from other servers" : "מאפשר למשתמשים בשרת זה לקבל שיתופים משרתים אחרים",
    "Federated Cloud" : "ענן מאוגד",
    "Your Federated Cloud ID:" : "מספר זיהוי הענן המאוגד שלך:",
    "Add to your website" : "הוספה לאתר האינטרנט שלך",
    "Share with me via Nextcloud" : "שיתוף איתי באמצעות Nextcloud",
    "HTML Code:" : "קוד HTML:"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/he.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "האם לשתף את השיתוף החיצוני {name} שהתקבל מ- {owner}@{remote}?",
    "Remote share" : "שיתוף חיצוני",
    "Remote share password" : "סיסמת שיתוף חיצוני",
    "Cancel" : "ביטול",
    "Add remote share" : "הוספת שיתוף חיצוני",
    "Copy" : "העתק",
    "Copied!" : "הועתק!",
    "Not supported!" : "אין תמיכה!",
    "Press ⌘-C to copy." : "‎⌘-C להעתקה.",
    "Press Ctrl-C to copy." : "Ctrl-C להעתקה.",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "Server to server sharing is not enabled on this server" : "שיתוף שרת לשרת לא מופעל בשרת זה",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "File is already shared with %s" : "הקובץ כבר משותף עם %s",
    "Could not find share" : "לא ניתן למצוא את השיתוף",
    "Federated sharing" : "שיתוף מאוגד",
    "Accept" : "אישור",
    "Decline" : "סירוב",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "שיתוף איתי באמצעות מספר זהות שרת ה- #Nextcloud המאוגד שלי, ניתן לראות %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "שיתוף איתי באמצעות מספר זהות שרת ה- #Nextcloud המאוגד שלי",
    "Sharing" : "שיתוף",
    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
    "Open documentation" : "תיעוד פתוח",
    "Allow users on this server to receive shares from other servers" : "מאפשר למשתמשים בשרת זה לקבל שיתופים משרתים אחרים",
    "Federated Cloud" : "ענן מאוגד",
    "Your Federated Cloud ID:" : "מספר זיהוי הענן המאוגד שלך:",
    "Add to your website" : "הוספה לאתר האינטרנט שלך",
    "Share with me via Nextcloud" : "שיתוף איתי באמצעות Nextcloud",
    "HTML Code:" : "קוד HTML:",
    "Allow users on this server to send shares to other servers" : "מאפשר למשתמשים בשרת זה לשלוח שיתופים לשרתים אחרים"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
